@@ -4,7 +4,7 @@ BEGIN {
 }
 # ABSTRACT: An algorithmic MIDI drummer
 
-our $VERSION = '0.0701';
+our $VERSION = '0.08';
 
 use strict;
 use warnings;
@@ -115,6 +115,13 @@ sub _setup { # Where's my roadies, Man?
         $self->{-signature} = "$self->{-beats}/$self->{-divisions}";
     }
 
+    $self->{-score}->time_signature(
+        $self->{-beats},
+        sqrt( $self->{-divisions} ),
+        ( $self->{-divisions} == 8 ? 24 : 18 ),
+        8
+    );
+
     # Reset the backbeat if the signature is a 3 multiple.
     my $x = $self->{-beats} / 3;
     if ($x !~ /\./) {
@@ -577,7 +584,7 @@ MIDI::Simple::Drummer - An algorithmic MIDI drummer
 
 =head1 VERSION
 
-version 0.0701
+version 0.08
 
 =head1 SYNOPSIS
 
