@@ -14,6 +14,7 @@ sub new {
         -patch  => 25,
         -tr808  => 0,
         -rhythm => undef,
+        -pad    => 'kick',
         @_
     );
 }
@@ -29,7 +30,8 @@ sub _default_patterns {
         : $self->euclid($self->{-onsets}, $self->beats);
     for my $i ( @$rhythm ) {
         if ( $i eq 'x' ) {
-            $self->note($self->EIGHTH, $self->kick);
+            my $pad = $self->{-pad};
+            $self->note($self->EIGHTH, $self->$pad );
         }
         else {
             $self->rest($self->EIGHTH);
@@ -96,7 +98,7 @@ MIDI::Simple::Drummer::Euclidean
 
 =head1 VERSION
 
-version 0.0701
+version 0.08
 
 =head1 DESCRIPTION
 
